@@ -303,21 +303,7 @@ class PogoData:
             for raw_mon in mons:
                 if not raw_mon:
                     continue
-                if "evolution" in raw_mon:
-                    base_mon = self.get_mon(
-                        id=raw_mon.get("id"),
-                        form=raw_mon.get("form"),
-                        costume=raw_mon.get("costume")
-                    )
-                    for evo in base_mon.temp_evolutions:
-                        if evo.id == raw_mon.get("evolution"):
-                            mon = evo
-                            break
-                else:
-                    mon = self.get_mon(
-                        template=raw_mon.get("template"),
-                        costume=raw_mon.get("costume", 0)
-                    )
+                mon = self.get_mon(**raw_mon)
 
                 if mon:
                     self.raids.add_mon(level, mon)
@@ -329,7 +315,7 @@ class PogoData:
         for templateid, entry in self.get_gamemaster(r"^CHARACTER_.*", "invasionNpcDisplaySettings"):
             id_ = enums.get(templateid, 0)
 
-            grunt_info = info_grunts.get(str(id_))
+            grunt_info = info_grunts.get(str(id_), {})
             team = []
             if grunt_info:
                 for i, team_position in enumerate(grunt_info.get("lineup", {}).get("team", [])):
@@ -454,7 +440,7 @@ class PogoData:
                     mon._gen_asset()
 
         # Making Pokemon.evolutions attributes
-        for mon in self.mons:
+        def append_evolution(mon, to_append):
             evolutions = mon.raw.get("evolutionBranch", [])
             for evo_raw in evolutions:
                 if "temporaryEvolution" in evo_raw:
@@ -462,4 +448,9 @@ class PogoData:
                 evo = self.get_mon(
                     template=evo_raw.get("form", evo_raw["evolution"])
                 )
-                mon.evolutions.append(evo)
+                to_append.append(evo)
+                append_evolution(evo, to_append)
+        for mon in self.mons:
+            evos = []
+            append_evolution(mon, evos)
+            mon.evolutions = evos
